const fs = require('fs')
const chalk = require('chalk')
const inqurirer = require('inquirer')
const download = require('download-git-repo')
const ora = require('ora')
const rimraf = require('rimraf')
const spinner = ora(chalk.yellow('Loading the template, wait a moment...'))

const questions = [
  {
    type: 'input',
    name: 'project',
    message: 'input you project name',
    default: 'cli-pro'
  },
  {
    type: 'input',
    name: 'description',
    message: 'description the project info',
    default: 'A CLI for Vue project'
  },
  {
    type: 'input',
    name: 'author',
    message: 'Author of the project',
    default: 'xxx'
  },
  {
    type: 'input',
    name: 'license',
    message: 'License of the project',
    default: 'MIT'
  },
  {
    type: 'confirm',
    name: 'private',
    message: 'is private of the project',
    default: true
  },
  {
    type: 'list',
    name: 'template',
    message: 'choise the template what you want',
    choices: ['webpack', 'simple', 'webpack-simple']
  }
]


module.exports = function() {
  inqurirer.prompt(questions).then(({ project, description, author, license, private, template }) => {
    
    spinner.start()
    rimraf.sync(project)

    download(`vuejs-templates/${template}`, project, error => {
      spinner.stop()

      if (error) {
        spinner.fail('can\'t Loading the template')
        return
      }

      
      fs.readFile(`./${project}/package.json`, 'utf8', (err, data) => {
        if (err) {
          console.log(err)
          return
        }
        const pkg = JSON.parse(data)
        pkg.name = project
        pkg.description = description
        pkg.author =  author
        pkg.license = license
        pkg.private = private
        pkg.scripts.dev = 'npm run dev'

        const newPkg = JSON.stringify(pkg, null, 2)

        fs.writeFile(`./${project}/package.json`, newPkg, 'utf8', err => {
          if (err) {
            console.log(err)
            return
          }

          console.log('')
          console.log(chalk.green(`√ ✨ ✨ ✨ ✨ ✨  Generate Project Success ✨ ✨ ✨ ✨ ✨`))

          console.log('')
          console.log(`${chalk.bgMagenta.white.bold('================== Run Application ==================')}`)
          console.log(`
            ${chalk.cyan(`$ cd ${project}`)}
            ${chalk.cyan('$ npm install')}
            ${chalk.cyan('$ npm run dev')}
          `)
          console.log(`${chalk.bgMagenta.white.bold('================== Run Application ==================')}`)
          console.log('')
        })
      })
    })
  })
}